#include <stdio.h>
#include <string.h>

#define LINELEN 2048
#define NUMTOKENS 512
static char inputLine[LINELEN];
static char *tokens[NUMTOKENS];

typedef struct {
  char *name;
  void (*func)();
} signalFunction;

extern void TestIO1_I_A();
extern void TestIO1_I_B();
extern void TestIO1_I_C();

static signalFunction signalFunctions[] =
{
  { "A", &TestIO1_I_A },
  { "B", &TestIO1_I_B },
  { "C", &TestIO1_I_C },
  { 0, 0 }
};

/*
  Split the input line into strings on space boundaries
 */
void parseLine()
{
  char **nextToken = tokens;
  char *c = inputLine;

  for (;;) {
    while (*c == ' ') c++;
    if (*c == '\n' || *c == '\0') break;
    *nextToken++ = c;
    while (*c != ' ' && *c != '\n' && *c != '\0') c++;
    *c++ = '\0';
  }
  *nextToken = NULL;
}

static char output_D;
static char output_E;
static char output_F;

static void printOutputs()
{
  printf(">");
  if (output_D) printf(" D");
  if (output_E) printf(" E");
  if (output_F) printf(" F");
  printf("\n");
}

static void resetOutputs()
{
  output_D =
  output_E =
  output_F = 0;
}

void TestIO1_O_D()
{
  output_D = 1;
}

void TestIO1_O_E()
{
  output_E = 1;
}

void TestIO1_O_F()
{
  output_F = 1;
}

int main(int argc, char *argv[])
{
  char **token;
  signalFunction *sf;

  TestIO1_reset();
  
  while ( fgets(inputLine, LINELEN, stdin) != NULL ) {
    parseLine();

    for ( token = tokens ; *token != 0 ; token++ ) {
      for ( sf = signalFunctions ; sf->name != 0 ; sf++ ) {
	if (strcmp(sf->name, *token) == 0) {
	  (sf->func)();
	  break;
	}
      }
      if (sf->name == 0) {
	fprintf(stderr, "Unrecognized input '%s'\n", *token);
	return 1;
      }
    }
        
    resetOutputs();
    TestIO1();
    printOutputs();
  }
  return 0;
}


